import Web3 from 'web3';
import Contract from "web3/eth/contract";
import { ABIDefinition } from "web3/eth/abi";
import { Tx } from "web3/eth/types";
import { BigNumber, UInt } from 'set-protocol-utils';
import { BaseContract } from '../base_contract';
export declare class CoreMockContract extends BaseContract {
    withdrawModule: {
        sendTransactionAsync(_from: string, _to: string, _token: string, _quantity: BigNumber, txData?: Tx): Promise<string>;
        estimateGasAsync(_from: string, _to: string, _token: string, _quantity: BigNumber, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_from: string, _to: string, _token: string, _quantity: BigNumber, txData?: Tx): string;
        callAsync(_from: string, _to: string, _token: string, _quantity: BigNumber, txData?: Tx): Promise<void>;
    };
    validFactories: {
        callAsync(_factory: string, defaultBlock?: any): Promise<boolean>;
    };
    removeExchange: {
        sendTransactionAsync(_exchangeId: UInt, _exchange: string, txData?: Tx): Promise<string>;
        estimateGasAsync(_exchangeId: UInt, _exchange: string, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_exchangeId: UInt, _exchange: string, txData?: Tx): string;
        callAsync(_exchangeId: UInt, _exchange: string, txData?: Tx): Promise<void>;
    };
    timeLockedUpgrades: {
        callAsync(index_0: string, defaultBlock?: any): Promise<BigNumber>;
    };
    reenableSet: {
        sendTransactionAsync(_set: string, txData?: Tx): Promise<string>;
        estimateGasAsync(_set: string, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_set: string, txData?: Tx): string;
        callAsync(_set: string, txData?: Tx): Promise<void>;
    };
    redeemAndWithdrawTo: {
        sendTransactionAsync(_set: string, _to: string, _quantity: BigNumber, _toExclude: BigNumber, txData?: Tx): Promise<string>;
        estimateGasAsync(_set: string, _to: string, _quantity: BigNumber, _toExclude: BigNumber, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_set: string, _to: string, _quantity: BigNumber, _toExclude: BigNumber, txData?: Tx): string;
        callAsync(_set: string, _to: string, _quantity: BigNumber, _toExclude: BigNumber, txData?: Tx): Promise<void>;
    };
    redeem: {
        sendTransactionAsync(_set: string, _quantity: BigNumber, txData?: Tx): Promise<string>;
        estimateGasAsync(_set: string, _quantity: BigNumber, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_set: string, _quantity: BigNumber, txData?: Tx): string;
        callAsync(_set: string, _quantity: BigNumber, txData?: Tx): Promise<void>;
    };
    addModule: {
        sendTransactionAsync(_module: string, txData?: Tx): Promise<string>;
        estimateGasAsync(_module: string, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_module: string, txData?: Tx): string;
        callAsync(_module: string, txData?: Tx): Promise<void>;
    };
    exchanges: {
        callAsync(defaultBlock?: any): Promise<string[]>;
    };
    addFactory: {
        sendTransactionAsync(_factory: string, txData?: Tx): Promise<string>;
        estimateGasAsync(_factory: string, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_factory: string, txData?: Tx): string;
        callAsync(_factory: string, txData?: Tx): Promise<void>;
    };
    batchDeposit: {
        sendTransactionAsync(_tokens: string[], _quantities: BigNumber[], txData?: Tx): Promise<string>;
        estimateGasAsync(_tokens: string[], _quantities: BigNumber[], txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_tokens: string[], _quantities: BigNumber[], txData?: Tx): string;
        callAsync(_tokens: string[], _quantities: BigNumber[], txData?: Tx): Promise<void>;
    };
    batchIncrementTokenOwnerModule: {
        sendTransactionAsync(_tokens: string[], _owner: string, _quantities: BigNumber[], txData?: Tx): Promise<string>;
        estimateGasAsync(_tokens: string[], _owner: string, _quantities: BigNumber[], txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_tokens: string[], _owner: string, _quantities: BigNumber[], txData?: Tx): string;
        callAsync(_tokens: string[], _owner: string, _quantities: BigNumber[], txData?: Tx): Promise<void>;
    };
    removePriceLibrary: {
        sendTransactionAsync(_priceLibrary: string, txData?: Tx): Promise<string>;
        estimateGasAsync(_priceLibrary: string, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_priceLibrary: string, txData?: Tx): string;
        callAsync(_priceLibrary: string, txData?: Tx): Promise<void>;
    };
    deposit: {
        sendTransactionAsync(_token: string, _quantity: BigNumber, txData?: Tx): Promise<string>;
        estimateGasAsync(_token: string, _quantity: BigNumber, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_token: string, _quantity: BigNumber, txData?: Tx): string;
        callAsync(_token: string, _quantity: BigNumber, txData?: Tx): Promise<void>;
    };
    removeFactory: {
        sendTransactionAsync(_factory: string, txData?: Tx): Promise<string>;
        estimateGasAsync(_factory: string, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_factory: string, txData?: Tx): string;
        callAsync(_factory: string, txData?: Tx): Promise<void>;
    };
    addExchange: {
        sendTransactionAsync(_exchangeId: UInt, _exchange: string, txData?: Tx): Promise<string>;
        estimateGasAsync(_exchangeId: UInt, _exchange: string, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_exchangeId: UInt, _exchange: string, txData?: Tx): string;
        callAsync(_exchangeId: UInt, _exchange: string, txData?: Tx): Promise<void>;
    };
    batchTransferModule: {
        sendTransactionAsync(_tokens: string[], _quantities: BigNumber[], _from: string, _to: string, txData?: Tx): Promise<string>;
        estimateGasAsync(_tokens: string[], _quantities: BigNumber[], _from: string, _to: string, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_tokens: string[], _quantities: BigNumber[], _from: string, _to: string, txData?: Tx): string;
        callAsync(_tokens: string[], _quantities: BigNumber[], _from: string, _to: string, txData?: Tx): Promise<void>;
    };
    setOperationState: {
        sendTransactionAsync(_operationState: UInt, txData?: Tx): Promise<string>;
        estimateGasAsync(_operationState: UInt, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_operationState: UInt, txData?: Tx): string;
        callAsync(_operationState: UInt, txData?: Tx): Promise<void>;
    };
    setTokens: {
        callAsync(defaultBlock?: any): Promise<string[]>;
    };
    batchTransferBalanceModule: {
        sendTransactionAsync(_tokens: string[], _from: string, _to: string, _quantities: BigNumber[], txData?: Tx): Promise<string>;
        estimateGasAsync(_tokens: string[], _from: string, _to: string, _quantities: BigNumber[], txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_tokens: string[], _from: string, _to: string, _quantities: BigNumber[], txData?: Tx): string;
        callAsync(_tokens: string[], _from: string, _to: string, _quantities: BigNumber[], txData?: Tx): Promise<void>;
    };
    exchangeIds: {
        callAsync(_exchangeId: UInt, defaultBlock?: any): Promise<string>;
    };
    redeemModule: {
        sendTransactionAsync(_burnAddress: string, _incrementAddress: string, _set: string, _quantity: BigNumber, txData?: Tx): Promise<string>;
        estimateGasAsync(_burnAddress: string, _incrementAddress: string, _set: string, _quantity: BigNumber, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_burnAddress: string, _incrementAddress: string, _set: string, _quantity: BigNumber, txData?: Tx): string;
        callAsync(_burnAddress: string, _incrementAddress: string, _set: string, _quantity: BigNumber, txData?: Tx): Promise<void>;
    };
    internalTransfer: {
        sendTransactionAsync(_token: string, _to: string, _quantity: BigNumber, txData?: Tx): Promise<string>;
        estimateGasAsync(_token: string, _to: string, _quantity: BigNumber, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_token: string, _to: string, _quantity: BigNumber, txData?: Tx): string;
        callAsync(_token: string, _to: string, _quantity: BigNumber, txData?: Tx): Promise<void>;
    };
    createSet: {
        sendTransactionAsync(_factory: string, _components: string[], _units: BigNumber[], _naturalUnit: BigNumber, _name: string, _symbol: string, _callData: string, txData?: Tx): Promise<string>;
        estimateGasAsync(_factory: string, _components: string[], _units: BigNumber[], _naturalUnit: BigNumber, _name: string, _symbol: string, _callData: string, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_factory: string, _components: string[], _units: BigNumber[], _naturalUnit: BigNumber, _name: string, _symbol: string, _callData: string, txData?: Tx): string;
        callAsync(_factory: string, _components: string[], _units: BigNumber[], _naturalUnit: BigNumber, _name: string, _symbol: string, _callData: string, txData?: Tx): Promise<string>;
    };
    validModules: {
        callAsync(_module: string, defaultBlock?: any): Promise<boolean>;
    };
    transferProxy: {
        callAsync(defaultBlock?: any): Promise<string>;
    };
    renounceOwnership: {
        sendTransactionAsync(txData?: Tx): Promise<string>;
        estimateGasAsync(txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(txData?: Tx): string;
        callAsync(txData?: Tx): Promise<void>;
    };
    operationState: {
        callAsync(defaultBlock?: any): Promise<BigNumber>;
    };
    issueTo: {
        sendTransactionAsync(_recipient: string, _set: string, _quantity: BigNumber, txData?: Tx): Promise<string>;
        estimateGasAsync(_recipient: string, _set: string, _quantity: BigNumber, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_recipient: string, _set: string, _quantity: BigNumber, txData?: Tx): string;
        callAsync(_recipient: string, _set: string, _quantity: BigNumber, txData?: Tx): Promise<void>;
    };
    disableSet: {
        sendTransactionAsync(_set: string, txData?: Tx): Promise<string>;
        estimateGasAsync(_set: string, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_set: string, txData?: Tx): string;
        callAsync(_set: string, txData?: Tx): Promise<void>;
    };
    timeLockPeriod: {
        callAsync(defaultBlock?: any): Promise<BigNumber>;
    };
    issueInVaultModule: {
        sendTransactionAsync(_recipient: string, _set: string, _quantity: BigNumber, txData?: Tx): Promise<string>;
        estimateGasAsync(_recipient: string, _set: string, _quantity: BigNumber, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_recipient: string, _set: string, _quantity: BigNumber, txData?: Tx): string;
        callAsync(_recipient: string, _set: string, _quantity: BigNumber, txData?: Tx): Promise<void>;
    };
    issueModule: {
        sendTransactionAsync(_componentOwner: string, _setRecipient: string, _set: string, _quantity: BigNumber, txData?: Tx): Promise<string>;
        estimateGasAsync(_componentOwner: string, _setRecipient: string, _set: string, _quantity: BigNumber, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_componentOwner: string, _setRecipient: string, _set: string, _quantity: BigNumber, txData?: Tx): string;
        callAsync(_componentOwner: string, _setRecipient: string, _set: string, _quantity: BigNumber, txData?: Tx): Promise<void>;
    };
    issue: {
        sendTransactionAsync(_set: string, _quantity: BigNumber, txData?: Tx): Promise<string>;
        estimateGasAsync(_set: string, _quantity: BigNumber, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_set: string, _quantity: BigNumber, txData?: Tx): string;
        callAsync(_set: string, _quantity: BigNumber, txData?: Tx): Promise<void>;
    };
    owner: {
        callAsync(defaultBlock?: any): Promise<string>;
    };
    isOwner: {
        callAsync(defaultBlock?: any): Promise<boolean>;
    };
    setTimeLockPeriod: {
        sendTransactionAsync(_timeLockPeriod: BigNumber, txData?: Tx): Promise<string>;
        estimateGasAsync(_timeLockPeriod: BigNumber, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_timeLockPeriod: BigNumber, txData?: Tx): string;
        callAsync(_timeLockPeriod: BigNumber, txData?: Tx): Promise<void>;
    };
    removeModule: {
        sendTransactionAsync(_module: string, txData?: Tx): Promise<string>;
        estimateGasAsync(_module: string, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_module: string, txData?: Tx): string;
        callAsync(_module: string, txData?: Tx): Promise<void>;
    };
    validPriceLibraries: {
        callAsync(_priceLibrary: string, defaultBlock?: any): Promise<boolean>;
    };
    issueInVault: {
        sendTransactionAsync(_set: string, _quantity: BigNumber, txData?: Tx): Promise<string>;
        estimateGasAsync(_set: string, _quantity: BigNumber, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_set: string, _quantity: BigNumber, txData?: Tx): string;
        callAsync(_set: string, _quantity: BigNumber, txData?: Tx): Promise<void>;
    };
    redeemInVault: {
        sendTransactionAsync(_set: string, _quantity: BigNumber, txData?: Tx): Promise<string>;
        estimateGasAsync(_set: string, _quantity: BigNumber, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_set: string, _quantity: BigNumber, txData?: Tx): string;
        callAsync(_set: string, _quantity: BigNumber, txData?: Tx): Promise<void>;
    };
    state: {
        callAsync(defaultBlock?: any): Promise<[BigNumber, string, string, string, string]>;
    };
    batchDecrementTokenOwnerModule: {
        sendTransactionAsync(_tokens: string[], _owner: string, _quantities: BigNumber[], txData?: Tx): Promise<string>;
        estimateGasAsync(_tokens: string[], _owner: string, _quantities: BigNumber[], txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_tokens: string[], _owner: string, _quantities: BigNumber[], txData?: Tx): string;
        callAsync(_tokens: string[], _owner: string, _quantities: BigNumber[], txData?: Tx): Promise<void>;
    };
    batchDepositModule: {
        sendTransactionAsync(_from: string, _to: string, _tokens: string[], _quantities: BigNumber[], txData?: Tx): Promise<string>;
        estimateGasAsync(_from: string, _to: string, _tokens: string[], _quantities: BigNumber[], txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_from: string, _to: string, _tokens: string[], _quantities: BigNumber[], txData?: Tx): string;
        callAsync(_from: string, _to: string, _tokens: string[], _quantities: BigNumber[], txData?: Tx): Promise<void>;
    };
    priceLibraries: {
        callAsync(defaultBlock?: any): Promise<string[]>;
    };
    disabledSets: {
        callAsync(_set: string, defaultBlock?: any): Promise<boolean>;
    };
    depositModule: {
        sendTransactionAsync(_from: string, _to: string, _token: string, _quantity: BigNumber, txData?: Tx): Promise<string>;
        estimateGasAsync(_from: string, _to: string, _token: string, _quantity: BigNumber, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_from: string, _to: string, _token: string, _quantity: BigNumber, txData?: Tx): string;
        callAsync(_from: string, _to: string, _token: string, _quantity: BigNumber, txData?: Tx): Promise<void>;
    };
    batchWithdraw: {
        sendTransactionAsync(_tokens: string[], _quantities: BigNumber[], txData?: Tx): Promise<string>;
        estimateGasAsync(_tokens: string[], _quantities: BigNumber[], txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_tokens: string[], _quantities: BigNumber[], txData?: Tx): string;
        callAsync(_tokens: string[], _quantities: BigNumber[], txData?: Tx): Promise<void>;
    };
    addPriceLibrary: {
        sendTransactionAsync(_priceLibrary: string, txData?: Tx): Promise<string>;
        estimateGasAsync(_priceLibrary: string, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_priceLibrary: string, txData?: Tx): string;
        callAsync(_priceLibrary: string, txData?: Tx): Promise<void>;
    };
    redeemTo: {
        sendTransactionAsync(_recipient: string, _set: string, _quantity: BigNumber, txData?: Tx): Promise<string>;
        estimateGasAsync(_recipient: string, _set: string, _quantity: BigNumber, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_recipient: string, _set: string, _quantity: BigNumber, txData?: Tx): string;
        callAsync(_recipient: string, _set: string, _quantity: BigNumber, txData?: Tx): Promise<void>;
    };
    transferOwnership: {
        sendTransactionAsync(newOwner: string, txData?: Tx): Promise<string>;
        estimateGasAsync(newOwner: string, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(newOwner: string, txData?: Tx): string;
        callAsync(newOwner: string, txData?: Tx): Promise<void>;
    };
    withdraw: {
        sendTransactionAsync(_token: string, _quantity: BigNumber, txData?: Tx): Promise<string>;
        estimateGasAsync(_token: string, _quantity: BigNumber, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_token: string, _quantity: BigNumber, txData?: Tx): string;
        callAsync(_token: string, _quantity: BigNumber, txData?: Tx): Promise<void>;
    };
    modules: {
        callAsync(defaultBlock?: any): Promise<string[]>;
    };
    vault: {
        callAsync(defaultBlock?: any): Promise<string>;
    };
    transferModule: {
        sendTransactionAsync(_token: string, _quantity: BigNumber, _from: string, _to: string, txData?: Tx): Promise<string>;
        estimateGasAsync(_token: string, _quantity: BigNumber, _from: string, _to: string, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_token: string, _quantity: BigNumber, _from: string, _to: string, txData?: Tx): string;
        callAsync(_token: string, _quantity: BigNumber, _from: string, _to: string, txData?: Tx): Promise<void>;
    };
    factories: {
        callAsync(defaultBlock?: any): Promise<string[]>;
    };
    batchWithdrawModule: {
        sendTransactionAsync(_from: string, _to: string, _tokens: string[], _quantities: BigNumber[], txData?: Tx): Promise<string>;
        estimateGasAsync(_from: string, _to: string, _tokens: string[], _quantities: BigNumber[], txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_from: string, _to: string, _tokens: string[], _quantities: BigNumber[], txData?: Tx): string;
        callAsync(_from: string, _to: string, _tokens: string[], _quantities: BigNumber[], txData?: Tx): Promise<void>;
    };
    validSets: {
        callAsync(_set: string, defaultBlock?: any): Promise<boolean>;
    };
    mint: {
        sendTransactionAsync(_set: string, _issuer: string, _quantity: BigNumber, txData?: Tx): Promise<string>;
        estimateGasAsync(_set: string, _issuer: string, _quantity: BigNumber, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_set: string, _issuer: string, _quantity: BigNumber, txData?: Tx): string;
        callAsync(_set: string, _issuer: string, _quantity: BigNumber, txData?: Tx): Promise<void>;
    };
    burn: {
        sendTransactionAsync(_set: string, _from: string, _quantity: BigNumber, txData?: Tx): Promise<string>;
        estimateGasAsync(_set: string, _from: string, _quantity: BigNumber, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_set: string, _from: string, _quantity: BigNumber, txData?: Tx): string;
        callAsync(_set: string, _from: string, _quantity: BigNumber, txData?: Tx): Promise<void>;
    };
    addSet: {
        sendTransactionAsync(_set: string, txData?: Tx): Promise<string>;
        estimateGasAsync(_set: string, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_set: string, txData?: Tx): string;
        callAsync(_set: string, txData?: Tx): Promise<void>;
    };
    deploy(data: string, args: any[]): Promise<any>;
    static deployed(web3: Web3, defaults: Tx): Promise<CoreMockContract>;
    static at(address: string, web3: Web3, defaults: Tx): Promise<CoreMockContract>;
    constructor(web3ContractInstance: Contract, defaults: Tx);
    static getAbi(): ABIDefinition[];
}
