import Web3 from 'web3';
import Contract from "web3/eth/contract";
import { ABIDefinition } from "web3/eth/abi";
import { Tx } from "web3/eth/types";
import { BigNumber, UInt } from 'set-protocol-utils';
import { BaseContract } from '../base_contract';
export declare class CoreModuleInteractionContract extends BaseContract {
    validFactories: {
        callAsync(_factory: string, defaultBlock?: any): Promise<boolean>;
    };
    exchanges: {
        callAsync(defaultBlock?: any): Promise<string[]>;
    };
    setTokens: {
        callAsync(defaultBlock?: any): Promise<string[]>;
    };
    exchangeIds: {
        callAsync(_exchangeId: UInt, defaultBlock?: any): Promise<string>;
    };
    validModules: {
        callAsync(_module: string, defaultBlock?: any): Promise<boolean>;
    };
    transferProxy: {
        callAsync(defaultBlock?: any): Promise<string>;
    };
    operationState: {
        callAsync(defaultBlock?: any): Promise<BigNumber>;
    };
    validPriceLibraries: {
        callAsync(_priceLibrary: string, defaultBlock?: any): Promise<boolean>;
    };
    state: {
        callAsync(defaultBlock?: any): Promise<[BigNumber, string, string, string, string]>;
    };
    priceLibraries: {
        callAsync(defaultBlock?: any): Promise<string[]>;
    };
    disabledSets: {
        callAsync(_set: string, defaultBlock?: any): Promise<boolean>;
    };
    modules: {
        callAsync(defaultBlock?: any): Promise<string[]>;
    };
    vault: {
        callAsync(defaultBlock?: any): Promise<string>;
    };
    factories: {
        callAsync(defaultBlock?: any): Promise<string[]>;
    };
    validSets: {
        callAsync(_set: string, defaultBlock?: any): Promise<boolean>;
    };
    depositModule: {
        sendTransactionAsync(_from: string, _to: string, _token: string, _quantity: BigNumber, txData?: Tx): Promise<string>;
        estimateGasAsync(_from: string, _to: string, _token: string, _quantity: BigNumber, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_from: string, _to: string, _token: string, _quantity: BigNumber, txData?: Tx): string;
        callAsync(_from: string, _to: string, _token: string, _quantity: BigNumber, txData?: Tx): Promise<void>;
    };
    batchDepositModule: {
        sendTransactionAsync(_from: string, _to: string, _tokens: string[], _quantities: BigNumber[], txData?: Tx): Promise<string>;
        estimateGasAsync(_from: string, _to: string, _tokens: string[], _quantities: BigNumber[], txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_from: string, _to: string, _tokens: string[], _quantities: BigNumber[], txData?: Tx): string;
        callAsync(_from: string, _to: string, _tokens: string[], _quantities: BigNumber[], txData?: Tx): Promise<void>;
    };
    withdrawModule: {
        sendTransactionAsync(_from: string, _to: string, _token: string, _quantity: BigNumber, txData?: Tx): Promise<string>;
        estimateGasAsync(_from: string, _to: string, _token: string, _quantity: BigNumber, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_from: string, _to: string, _token: string, _quantity: BigNumber, txData?: Tx): string;
        callAsync(_from: string, _to: string, _token: string, _quantity: BigNumber, txData?: Tx): Promise<void>;
    };
    batchWithdrawModule: {
        sendTransactionAsync(_from: string, _to: string, _tokens: string[], _quantities: BigNumber[], txData?: Tx): Promise<string>;
        estimateGasAsync(_from: string, _to: string, _tokens: string[], _quantities: BigNumber[], txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_from: string, _to: string, _tokens: string[], _quantities: BigNumber[], txData?: Tx): string;
        callAsync(_from: string, _to: string, _tokens: string[], _quantities: BigNumber[], txData?: Tx): Promise<void>;
    };
    issueModule: {
        sendTransactionAsync(_componentOwner: string, _setRecipient: string, _set: string, _quantity: BigNumber, txData?: Tx): Promise<string>;
        estimateGasAsync(_componentOwner: string, _setRecipient: string, _set: string, _quantity: BigNumber, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_componentOwner: string, _setRecipient: string, _set: string, _quantity: BigNumber, txData?: Tx): string;
        callAsync(_componentOwner: string, _setRecipient: string, _set: string, _quantity: BigNumber, txData?: Tx): Promise<void>;
    };
    issueInVaultModule: {
        sendTransactionAsync(_recipient: string, _set: string, _quantity: BigNumber, txData?: Tx): Promise<string>;
        estimateGasAsync(_recipient: string, _set: string, _quantity: BigNumber, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_recipient: string, _set: string, _quantity: BigNumber, txData?: Tx): string;
        callAsync(_recipient: string, _set: string, _quantity: BigNumber, txData?: Tx): Promise<void>;
    };
    redeemModule: {
        sendTransactionAsync(_burnAddress: string, _incrementAddress: string, _set: string, _quantity: BigNumber, txData?: Tx): Promise<string>;
        estimateGasAsync(_burnAddress: string, _incrementAddress: string, _set: string, _quantity: BigNumber, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_burnAddress: string, _incrementAddress: string, _set: string, _quantity: BigNumber, txData?: Tx): string;
        callAsync(_burnAddress: string, _incrementAddress: string, _set: string, _quantity: BigNumber, txData?: Tx): Promise<void>;
    };
    batchIncrementTokenOwnerModule: {
        sendTransactionAsync(_tokens: string[], _owner: string, _quantities: BigNumber[], txData?: Tx): Promise<string>;
        estimateGasAsync(_tokens: string[], _owner: string, _quantities: BigNumber[], txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_tokens: string[], _owner: string, _quantities: BigNumber[], txData?: Tx): string;
        callAsync(_tokens: string[], _owner: string, _quantities: BigNumber[], txData?: Tx): Promise<void>;
    };
    batchDecrementTokenOwnerModule: {
        sendTransactionAsync(_tokens: string[], _owner: string, _quantities: BigNumber[], txData?: Tx): Promise<string>;
        estimateGasAsync(_tokens: string[], _owner: string, _quantities: BigNumber[], txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_tokens: string[], _owner: string, _quantities: BigNumber[], txData?: Tx): string;
        callAsync(_tokens: string[], _owner: string, _quantities: BigNumber[], txData?: Tx): Promise<void>;
    };
    batchTransferBalanceModule: {
        sendTransactionAsync(_tokens: string[], _from: string, _to: string, _quantities: BigNumber[], txData?: Tx): Promise<string>;
        estimateGasAsync(_tokens: string[], _from: string, _to: string, _quantities: BigNumber[], txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_tokens: string[], _from: string, _to: string, _quantities: BigNumber[], txData?: Tx): string;
        callAsync(_tokens: string[], _from: string, _to: string, _quantities: BigNumber[], txData?: Tx): Promise<void>;
    };
    transferModule: {
        sendTransactionAsync(_token: string, _quantity: BigNumber, _from: string, _to: string, txData?: Tx): Promise<string>;
        estimateGasAsync(_token: string, _quantity: BigNumber, _from: string, _to: string, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_token: string, _quantity: BigNumber, _from: string, _to: string, txData?: Tx): string;
        callAsync(_token: string, _quantity: BigNumber, _from: string, _to: string, txData?: Tx): Promise<void>;
    };
    batchTransferModule: {
        sendTransactionAsync(_tokens: string[], _quantities: BigNumber[], _from: string, _to: string, txData?: Tx): Promise<string>;
        estimateGasAsync(_tokens: string[], _quantities: BigNumber[], _from: string, _to: string, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_tokens: string[], _quantities: BigNumber[], _from: string, _to: string, txData?: Tx): string;
        callAsync(_tokens: string[], _quantities: BigNumber[], _from: string, _to: string, txData?: Tx): Promise<void>;
    };
    deploy(data: string, args: any[]): Promise<any>;
    static deployed(web3: Web3, defaults: Tx): Promise<CoreModuleInteractionContract>;
    static at(address: string, web3: Web3, defaults: Tx): Promise<CoreModuleInteractionContract>;
    constructor(web3ContractInstance: Contract, defaults: Tx);
    static getAbi(): ABIDefinition[];
}
