import Web3 from 'web3';
import Contract from "web3/eth/contract";
import { ABIDefinition } from "web3/eth/abi";
import { Tx } from "web3/eth/types";
import { BigNumber } from 'set-protocol-utils';
import { BaseContract } from '../base_contract';
export declare class LinearAuctionLiquidatorContract extends BaseContract {
    name: {
        callAsync(defaultBlock?: any): Promise<string>;
    };
    auctionPeriod: {
        callAsync(defaultBlock?: any): Promise<BigNumber>;
    };
    auctions: {
        callAsync(index_0: string, defaultBlock?: any): Promise<[{
            maxNaturalUnit: BigNumber;
            minimumBid: BigNumber;
            startTime: BigNumber;
            startingCurrentSets: BigNumber;
            remainingCurrentSets: BigNumber;
            combinedTokenArray: string[];
            combinedCurrentSetUnits: BigNumber[];
            combinedNextSetUnits: BigNumber[];
        }, BigNumber, BigNumber, BigNumber]>;
    };
    rangeEnd: {
        callAsync(defaultBlock?: any): Promise<BigNumber>;
    };
    rangeStart: {
        callAsync(defaultBlock?: any): Promise<BigNumber>;
    };
    oracleWhiteList: {
        callAsync(defaultBlock?: any): Promise<string>;
    };
    core: {
        callAsync(defaultBlock?: any): Promise<string>;
    };
    startRebalance: {
        sendTransactionAsync(_currentSet: string, _nextSet: string, _startingCurrentSetQuantity: BigNumber, _liquidatorData: string, txData?: Tx): Promise<string>;
        estimateGasAsync(_currentSet: string, _nextSet: string, _startingCurrentSetQuantity: BigNumber, _liquidatorData: string, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_currentSet: string, _nextSet: string, _startingCurrentSetQuantity: BigNumber, _liquidatorData: string, txData?: Tx): string;
        callAsync(_currentSet: string, _nextSet: string, _startingCurrentSetQuantity: BigNumber, _liquidatorData: string, txData?: Tx): Promise<void>;
    };
    placeBid: {
        sendTransactionAsync(_quantity: BigNumber, txData?: Tx): Promise<string>;
        estimateGasAsync(_quantity: BigNumber, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_quantity: BigNumber, txData?: Tx): string;
        callAsync(_quantity: BigNumber, txData?: Tx): Promise<{}>;
    };
    getBidPrice: {
        callAsync(_set: string, _quantity: BigNumber, defaultBlock?: any): Promise<{}>;
    };
    settleRebalance: {
        sendTransactionAsync(txData?: Tx): Promise<string>;
        estimateGasAsync(txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(txData?: Tx): string;
        callAsync(txData?: Tx): Promise<void>;
    };
    endFailedRebalance: {
        sendTransactionAsync(txData?: Tx): Promise<string>;
        estimateGasAsync(txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(txData?: Tx): string;
        callAsync(txData?: Tx): Promise<void>;
    };
    hasRebalanceFailed: {
        callAsync(_set: string, defaultBlock?: any): Promise<boolean>;
    };
    minimumBid: {
        callAsync(_set: string, defaultBlock?: any): Promise<BigNumber>;
    };
    remainingCurrentSets: {
        callAsync(_set: string, defaultBlock?: any): Promise<BigNumber>;
    };
    startingCurrentSets: {
        callAsync(_set: string, defaultBlock?: any): Promise<BigNumber>;
    };
    getCombinedTokenArray: {
        callAsync(_set: string, defaultBlock?: any): Promise<string[]>;
    };
    getCombinedCurrentSetUnits: {
        callAsync(_set: string, defaultBlock?: any): Promise<BigNumber[]>;
    };
    getCombinedNextSetUnits: {
        callAsync(_set: string, defaultBlock?: any): Promise<BigNumber[]>;
    };
    auctionPriceParameters: {
        callAsync(_set: string, defaultBlock?: any): Promise<{}>;
    };
    deploy(data: string, args: any[]): Promise<any>;
    static deployed(web3: Web3, defaults: Tx): Promise<LinearAuctionLiquidatorContract>;
    static at(address: string, web3: Web3, defaults: Tx): Promise<LinearAuctionLiquidatorContract>;
    constructor(web3ContractInstance: Contract, defaults: Tx);
    static getAbi(): ABIDefinition[];
}
