import Web3 from 'web3';
import Contract from "web3/eth/contract";
import { ABIDefinition } from "web3/eth/abi";
import { Tx } from "web3/eth/types";
import { BigNumber } from 'set-protocol-utils';
import { BaseContract } from '../base_contract';
export declare class RebalancingFailureContract extends BaseContract {
    unitShares: {
        callAsync(defaultBlock?: any): Promise<BigNumber>;
    };
    setLiquidator: {
        sendTransactionAsync(_newLiquidator: string, txData?: Tx): Promise<string>;
        estimateGasAsync(_newLiquidator: string, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_newLiquidator: string, txData?: Tx): string;
        callAsync(_newLiquidator: string, txData?: Tx): Promise<void>;
    };
    getUnits: {
        callAsync(defaultBlock?: any): Promise<BigNumber[]>;
    };
    entryFee: {
        callAsync(defaultBlock?: any): Promise<BigNumber>;
    };
    approve: {
        sendTransactionAsync(spender: string, value: BigNumber, txData?: Tx): Promise<string>;
        estimateGasAsync(spender: string, value: BigNumber, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(spender: string, value: BigNumber, txData?: Tx): string;
        callAsync(spender: string, value: BigNumber, txData?: Tx): Promise<boolean>;
    };
    liquidatorWhiteList: {
        callAsync(defaultBlock?: any): Promise<string>;
    };
    rebalanceInterval: {
        callAsync(defaultBlock?: any): Promise<BigNumber>;
    };
    totalSupply: {
        callAsync(defaultBlock?: any): Promise<BigNumber>;
    };
    rebalanceFailPeriod: {
        callAsync(defaultBlock?: any): Promise<BigNumber>;
    };
    tokenIsComponent: {
        callAsync(_tokenAddress: string, defaultBlock?: any): Promise<boolean>;
    };
    transferFrom: {
        sendTransactionAsync(from: string, to: string, value: BigNumber, txData?: Tx): Promise<string>;
        estimateGasAsync(from: string, to: string, value: BigNumber, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(from: string, to: string, value: BigNumber, txData?: Tx): string;
        callAsync(from: string, to: string, value: BigNumber, txData?: Tx): Promise<boolean>;
    };
    rebalanceFee: {
        callAsync(defaultBlock?: any): Promise<BigNumber>;
    };
    currentSet: {
        callAsync(defaultBlock?: any): Promise<string>;
    };
    increaseAllowance: {
        sendTransactionAsync(spender: string, addedValue: BigNumber, txData?: Tx): Promise<string>;
        estimateGasAsync(spender: string, addedValue: BigNumber, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(spender: string, addedValue: BigNumber, txData?: Tx): string;
        callAsync(spender: string, addedValue: BigNumber, txData?: Tx): Promise<boolean>;
    };
    liquidator: {
        callAsync(defaultBlock?: any): Promise<string>;
    };
    naturalUnit: {
        callAsync(defaultBlock?: any): Promise<BigNumber>;
    };
    rebalanceFeeCalculator: {
        callAsync(defaultBlock?: any): Promise<string>;
    };
    feeRecipient: {
        callAsync(defaultBlock?: any): Promise<string>;
    };
    manager: {
        callAsync(defaultBlock?: any): Promise<string>;
    };
    componentWhiteList: {
        callAsync(defaultBlock?: any): Promise<string>;
    };
    balanceOf: {
        callAsync(owner: string, defaultBlock?: any): Promise<BigNumber>;
    };
    rebalanceIndex: {
        callAsync(defaultBlock?: any): Promise<BigNumber>;
    };
    getComponents: {
        callAsync(defaultBlock?: any): Promise<string[]>;
    };
    rebalanceStartTime: {
        callAsync(defaultBlock?: any): Promise<BigNumber>;
    };
    decreaseAllowance: {
        sendTransactionAsync(spender: string, subtractedValue: BigNumber, txData?: Tx): Promise<string>;
        estimateGasAsync(spender: string, subtractedValue: BigNumber, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(spender: string, subtractedValue: BigNumber, txData?: Tx): string;
        callAsync(spender: string, subtractedValue: BigNumber, txData?: Tx): Promise<boolean>;
    };
    transfer: {
        sendTransactionAsync(to: string, value: BigNumber, txData?: Tx): Promise<string>;
        estimateGasAsync(to: string, value: BigNumber, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(to: string, value: BigNumber, txData?: Tx): string;
        callAsync(to: string, value: BigNumber, txData?: Tx): Promise<boolean>;
    };
    lastRebalanceTimestamp: {
        callAsync(defaultBlock?: any): Promise<BigNumber>;
    };
    factory: {
        callAsync(defaultBlock?: any): Promise<string>;
    };
    nextSet: {
        callAsync(defaultBlock?: any): Promise<string>;
    };
    SCALE_FACTOR: {
        callAsync(defaultBlock?: any): Promise<BigNumber>;
    };
    setManager: {
        sendTransactionAsync(_newManager: string, txData?: Tx): Promise<string>;
        estimateGasAsync(_newManager: string, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_newManager: string, txData?: Tx): string;
        callAsync(_newManager: string, txData?: Tx): Promise<void>;
    };
    allowance: {
        callAsync(owner: string, spender: string, defaultBlock?: any): Promise<BigNumber>;
    };
    setFeeRecipient: {
        sendTransactionAsync(_newFeeRecipient: string, txData?: Tx): Promise<string>;
        estimateGasAsync(_newFeeRecipient: string, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_newFeeRecipient: string, txData?: Tx): string;
        callAsync(_newFeeRecipient: string, txData?: Tx): Promise<void>;
    };
    setEntryFee: {
        sendTransactionAsync(_newEntryFee: BigNumber, txData?: Tx): Promise<string>;
        estimateGasAsync(_newEntryFee: BigNumber, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_newEntryFee: BigNumber, txData?: Tx): string;
        callAsync(_newEntryFee: BigNumber, txData?: Tx): Promise<void>;
    };
    hasBidded: {
        callAsync(defaultBlock?: any): Promise<boolean>;
    };
    core: {
        callAsync(defaultBlock?: any): Promise<string>;
    };
    rebalanceState: {
        callAsync(defaultBlock?: any): Promise<BigNumber>;
    };
    vault: {
        callAsync(defaultBlock?: any): Promise<string>;
    };
    deploy(data: string, args: any[]): Promise<any>;
    static deployed(web3: Web3, defaults: Tx): Promise<RebalancingFailureContract>;
    static at(address: string, web3: Web3, defaults: Tx): Promise<RebalancingFailureContract>;
    constructor(web3ContractInstance: Contract, defaults: Tx);
    static getAbi(): ABIDefinition[];
}
