import Web3 from 'web3';
import Contract from "web3/eth/contract";
import { ABIDefinition } from "web3/eth/abi";
import { Tx } from "web3/eth/types";
import { BigNumber } from 'set-protocol-utils';
import { BaseContract } from '../base_contract';
export declare class RebalancingSetTokenContract extends BaseContract {
    unitShares: {
        callAsync(defaultBlock?: any): Promise<BigNumber>;
    };
    name: {
        callAsync(defaultBlock?: any): Promise<string>;
    };
    approve: {
        sendTransactionAsync(spender: string, value: BigNumber, txData?: Tx): Promise<string>;
        estimateGasAsync(spender: string, value: BigNumber, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(spender: string, value: BigNumber, txData?: Tx): string;
        callAsync(spender: string, value: BigNumber, txData?: Tx): Promise<boolean>;
    };
    failedAuctionWithdrawComponents: {
        callAsync(index_0: BigNumber, defaultBlock?: any): Promise<string>;
    };
    rebalanceInterval: {
        callAsync(defaultBlock?: any): Promise<BigNumber>;
    };
    totalSupply: {
        callAsync(defaultBlock?: any): Promise<BigNumber>;
    };
    transferFrom: {
        sendTransactionAsync(from: string, to: string, value: BigNumber, txData?: Tx): Promise<string>;
        estimateGasAsync(from: string, to: string, value: BigNumber, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(from: string, to: string, value: BigNumber, txData?: Tx): string;
        callAsync(from: string, to: string, value: BigNumber, txData?: Tx): Promise<boolean>;
    };
    proposalPeriod: {
        callAsync(defaultBlock?: any): Promise<BigNumber>;
    };
    currentSet: {
        callAsync(defaultBlock?: any): Promise<string>;
    };
    decimals: {
        callAsync(defaultBlock?: any): Promise<BigNumber>;
    };
    increaseAllowance: {
        sendTransactionAsync(spender: string, addedValue: BigNumber, txData?: Tx): Promise<string>;
        estimateGasAsync(spender: string, addedValue: BigNumber, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(spender: string, addedValue: BigNumber, txData?: Tx): string;
        callAsync(spender: string, addedValue: BigNumber, txData?: Tx): Promise<boolean>;
    };
    naturalUnit: {
        callAsync(defaultBlock?: any): Promise<BigNumber>;
    };
    startingCurrentSetAmount: {
        callAsync(defaultBlock?: any): Promise<BigNumber>;
    };
    manager: {
        callAsync(defaultBlock?: any): Promise<string>;
    };
    biddingParameters: {
        callAsync(defaultBlock?: any): Promise<[BigNumber, BigNumber]>;
    };
    balanceOf: {
        callAsync(owner: string, defaultBlock?: any): Promise<BigNumber>;
    };
    symbol: {
        callAsync(defaultBlock?: any): Promise<string>;
    };
    auctionLibrary: {
        callAsync(defaultBlock?: any): Promise<string>;
    };
    decreaseAllowance: {
        sendTransactionAsync(spender: string, subtractedValue: BigNumber, txData?: Tx): Promise<string>;
        estimateGasAsync(spender: string, subtractedValue: BigNumber, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(spender: string, subtractedValue: BigNumber, txData?: Tx): string;
        callAsync(spender: string, subtractedValue: BigNumber, txData?: Tx): Promise<boolean>;
    };
    transfer: {
        sendTransactionAsync(to: string, value: BigNumber, txData?: Tx): Promise<string>;
        estimateGasAsync(to: string, value: BigNumber, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(to: string, value: BigNumber, txData?: Tx): string;
        callAsync(to: string, value: BigNumber, txData?: Tx): Promise<boolean>;
    };
    proposalStartTime: {
        callAsync(defaultBlock?: any): Promise<BigNumber>;
    };
    lastRebalanceTimestamp: {
        callAsync(defaultBlock?: any): Promise<BigNumber>;
    };
    factory: {
        callAsync(defaultBlock?: any): Promise<string>;
    };
    nextSet: {
        callAsync(defaultBlock?: any): Promise<string>;
    };
    auctionPriceParameters: {
        callAsync(defaultBlock?: any): Promise<[BigNumber, BigNumber, BigNumber, BigNumber]>;
    };
    allowance: {
        callAsync(owner: string, spender: string, defaultBlock?: any): Promise<BigNumber>;
    };
    core: {
        callAsync(defaultBlock?: any): Promise<string>;
    };
    rebalanceState: {
        callAsync(defaultBlock?: any): Promise<BigNumber>;
    };
    vault: {
        callAsync(defaultBlock?: any): Promise<string>;
    };
    componentWhiteListAddress: {
        callAsync(defaultBlock?: any): Promise<string>;
    };
    propose: {
        sendTransactionAsync(_nextSet: string, _auctionLibrary: string, _auctionTimeToPivot: BigNumber, _auctionStartPrice: BigNumber, _auctionPivotPrice: BigNumber, txData?: Tx): Promise<string>;
        estimateGasAsync(_nextSet: string, _auctionLibrary: string, _auctionTimeToPivot: BigNumber, _auctionStartPrice: BigNumber, _auctionPivotPrice: BigNumber, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_nextSet: string, _auctionLibrary: string, _auctionTimeToPivot: BigNumber, _auctionStartPrice: BigNumber, _auctionPivotPrice: BigNumber, txData?: Tx): string;
        callAsync(_nextSet: string, _auctionLibrary: string, _auctionTimeToPivot: BigNumber, _auctionStartPrice: BigNumber, _auctionPivotPrice: BigNumber, txData?: Tx): Promise<void>;
    };
    startRebalance: {
        sendTransactionAsync(txData?: Tx): Promise<string>;
        estimateGasAsync(txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(txData?: Tx): string;
        callAsync(txData?: Tx): Promise<void>;
    };
    settleRebalance: {
        sendTransactionAsync(txData?: Tx): Promise<string>;
        estimateGasAsync(txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(txData?: Tx): string;
        callAsync(txData?: Tx): Promise<void>;
    };
    placeBid: {
        sendTransactionAsync(_quantity: BigNumber, txData?: Tx): Promise<string>;
        estimateGasAsync(_quantity: BigNumber, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_quantity: BigNumber, txData?: Tx): string;
        callAsync(_quantity: BigNumber, txData?: Tx): Promise<[string[], BigNumber[], BigNumber[]]>;
    };
    endFailedAuction: {
        sendTransactionAsync(txData?: Tx): Promise<string>;
        estimateGasAsync(txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(txData?: Tx): string;
        callAsync(txData?: Tx): Promise<void>;
    };
    getBidPrice: {
        callAsync(_quantity: BigNumber, defaultBlock?: any): Promise<[BigNumber[], BigNumber[]]>;
    };
    mint: {
        sendTransactionAsync(_issuer: string, _quantity: BigNumber, txData?: Tx): Promise<string>;
        estimateGasAsync(_issuer: string, _quantity: BigNumber, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_issuer: string, _quantity: BigNumber, txData?: Tx): string;
        callAsync(_issuer: string, _quantity: BigNumber, txData?: Tx): Promise<void>;
    };
    burn: {
        sendTransactionAsync(_from: string, _quantity: BigNumber, txData?: Tx): Promise<string>;
        estimateGasAsync(_from: string, _quantity: BigNumber, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_from: string, _quantity: BigNumber, txData?: Tx): string;
        callAsync(_from: string, _quantity: BigNumber, txData?: Tx): Promise<void>;
    };
    setManager: {
        sendTransactionAsync(_newManager: string, txData?: Tx): Promise<string>;
        estimateGasAsync(_newManager: string, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_newManager: string, txData?: Tx): string;
        callAsync(_newManager: string, txData?: Tx): Promise<void>;
    };
    getComponents: {
        callAsync(defaultBlock?: any): Promise<string[]>;
    };
    getUnits: {
        callAsync(defaultBlock?: any): Promise<BigNumber[]>;
    };
    getBiddingParameters: {
        callAsync(defaultBlock?: any): Promise<BigNumber[]>;
    };
    getAuctionPriceParameters: {
        callAsync(defaultBlock?: any): Promise<BigNumber[]>;
    };
    tokenIsComponent: {
        callAsync(_tokenAddress: string, defaultBlock?: any): Promise<boolean>;
    };
    getCombinedTokenArrayLength: {
        callAsync(defaultBlock?: any): Promise<BigNumber>;
    };
    getCombinedTokenArray: {
        callAsync(defaultBlock?: any): Promise<string[]>;
    };
    getCombinedCurrentUnits: {
        callAsync(defaultBlock?: any): Promise<BigNumber[]>;
    };
    getCombinedNextSetUnits: {
        callAsync(defaultBlock?: any): Promise<BigNumber[]>;
    };
    getFailedAuctionWithdrawComponents: {
        callAsync(defaultBlock?: any): Promise<string[]>;
    };
    deploy(data: string, args: any[]): Promise<any>;
    static deployed(web3: Web3, defaults: Tx): Promise<RebalancingSetTokenContract>;
    static at(address: string, web3: Web3, defaults: Tx): Promise<RebalancingSetTokenContract>;
    constructor(web3ContractInstance: Contract, defaults: Tx);
    static getAbi(): ABIDefinition[];
}
