import Web3 from 'web3';
import Contract from "web3/eth/contract";
import { ABIDefinition } from "web3/eth/abi";
import { Tx } from "web3/eth/types";
import { BigNumber } from 'set-protocol-utils';
import { BaseContract } from '../base_contract';
export declare class StandardTokenWithFeeMockContract extends BaseContract {
    name: {
        callAsync(defaultBlock?: any): Promise<string>;
    };
    decimals: {
        callAsync(defaultBlock?: any): Promise<BigNumber>;
    };
    _totalSupply: {
        callAsync(defaultBlock?: any): Promise<BigNumber>;
    };
    _balances: {
        callAsync(index_0: string, defaultBlock?: any): Promise<BigNumber>;
    };
    symbol: {
        callAsync(defaultBlock?: any): Promise<string>;
    };
    _allowed: {
        callAsync(index_0: string, index_1: string, defaultBlock?: any): Promise<BigNumber>;
    };
    fee: {
        callAsync(defaultBlock?: any): Promise<BigNumber>;
    };
    transferFrom: {
        sendTransactionAsync(_from: string, _to: string, _value: BigNumber, txData?: Tx): Promise<string>;
        estimateGasAsync(_from: string, _to: string, _value: BigNumber, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_from: string, _to: string, _value: BigNumber, txData?: Tx): string;
        callAsync(_from: string, _to: string, _value: BigNumber, txData?: Tx): Promise<boolean>;
    };
    transfer: {
        sendTransactionAsync(_to: string, _value: BigNumber, txData?: Tx): Promise<string>;
        estimateGasAsync(_to: string, _value: BigNumber, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_to: string, _value: BigNumber, txData?: Tx): string;
        callAsync(_to: string, _value: BigNumber, txData?: Tx): Promise<boolean>;
    };
    setFee: {
        sendTransactionAsync(_fee: BigNumber, txData?: Tx): Promise<string>;
        estimateGasAsync(_fee: BigNumber, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_fee: BigNumber, txData?: Tx): string;
        callAsync(_fee: BigNumber, txData?: Tx): Promise<boolean>;
    };
    totalSupply: {
        callAsync(defaultBlock?: any): Promise<BigNumber>;
    };
    balanceOf: {
        callAsync(owner: string, defaultBlock?: any): Promise<BigNumber>;
    };
    allowance: {
        callAsync(owner: string, spender: string, defaultBlock?: any): Promise<BigNumber>;
    };
    approve: {
        sendTransactionAsync(spender: string, value: BigNumber, txData?: Tx): Promise<string>;
        estimateGasAsync(spender: string, value: BigNumber, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(spender: string, value: BigNumber, txData?: Tx): string;
        callAsync(spender: string, value: BigNumber, txData?: Tx): Promise<boolean>;
    };
    increaseAllowance: {
        sendTransactionAsync(spender: string, addedValue: BigNumber, txData?: Tx): Promise<string>;
        estimateGasAsync(spender: string, addedValue: BigNumber, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(spender: string, addedValue: BigNumber, txData?: Tx): string;
        callAsync(spender: string, addedValue: BigNumber, txData?: Tx): Promise<boolean>;
    };
    decreaseAllowance: {
        sendTransactionAsync(spender: string, subtractedValue: BigNumber, txData?: Tx): Promise<string>;
        estimateGasAsync(spender: string, subtractedValue: BigNumber, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(spender: string, subtractedValue: BigNumber, txData?: Tx): string;
        callAsync(spender: string, subtractedValue: BigNumber, txData?: Tx): Promise<boolean>;
    };
    deploy(data: string, args: any[]): Promise<any>;
    static deployed(web3: Web3, defaults: Tx): Promise<StandardTokenWithFeeMockContract>;
    static at(address: string, web3: Web3, defaults: Tx): Promise<StandardTokenWithFeeMockContract>;
    constructor(web3ContractInstance: Contract, defaults: Tx);
    static getAbi(): ABIDefinition[];
}
