import Web3 from 'web3';
import Contract from "web3/eth/contract";
import { ABIDefinition } from "web3/eth/abi";
import { Tx } from "web3/eth/types";
import { BigNumber } from 'set-protocol-utils';
import { BaseContract } from '../base_contract';
export declare class VaultContract extends BaseContract {
    timeLockedUpgrades: {
        callAsync(index_0: string, defaultBlock?: any): Promise<BigNumber>;
    };
    addAuthorizedAddress: {
        sendTransactionAsync(_authTarget: string, txData?: Tx): Promise<string>;
        estimateGasAsync(_authTarget: string, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_authTarget: string, txData?: Tx): string;
        callAsync(_authTarget: string, txData?: Tx): Promise<void>;
    };
    authorities: {
        callAsync(index_0: BigNumber, defaultBlock?: any): Promise<string>;
    };
    removeAuthorizedAddress: {
        sendTransactionAsync(_authTarget: string, txData?: Tx): Promise<string>;
        estimateGasAsync(_authTarget: string, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_authTarget: string, txData?: Tx): string;
        callAsync(_authTarget: string, txData?: Tx): Promise<void>;
    };
    renounceOwnership: {
        sendTransactionAsync(txData?: Tx): Promise<string>;
        estimateGasAsync(txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(txData?: Tx): string;
        callAsync(txData?: Tx): Promise<void>;
    };
    timeLockPeriod: {
        callAsync(defaultBlock?: any): Promise<BigNumber>;
    };
    owner: {
        callAsync(defaultBlock?: any): Promise<string>;
    };
    isOwner: {
        callAsync(defaultBlock?: any): Promise<boolean>;
    };
    setTimeLockPeriod: {
        sendTransactionAsync(_timeLockPeriod: BigNumber, txData?: Tx): Promise<string>;
        estimateGasAsync(_timeLockPeriod: BigNumber, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_timeLockPeriod: BigNumber, txData?: Tx): string;
        callAsync(_timeLockPeriod: BigNumber, txData?: Tx): Promise<void>;
    };
    authorized: {
        callAsync(index_0: string, defaultBlock?: any): Promise<boolean>;
    };
    balances: {
        callAsync(index_0: string, index_1: string, defaultBlock?: any): Promise<BigNumber>;
    };
    getAuthorizedAddresses: {
        callAsync(defaultBlock?: any): Promise<string[]>;
    };
    transferOwnership: {
        sendTransactionAsync(newOwner: string, txData?: Tx): Promise<string>;
        estimateGasAsync(newOwner: string, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(newOwner: string, txData?: Tx): string;
        callAsync(newOwner: string, txData?: Tx): Promise<void>;
    };
    withdrawTo: {
        sendTransactionAsync(_token: string, _to: string, _quantity: BigNumber, txData?: Tx): Promise<string>;
        estimateGasAsync(_token: string, _to: string, _quantity: BigNumber, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_token: string, _to: string, _quantity: BigNumber, txData?: Tx): string;
        callAsync(_token: string, _to: string, _quantity: BigNumber, txData?: Tx): Promise<void>;
    };
    incrementTokenOwner: {
        sendTransactionAsync(_token: string, _owner: string, _quantity: BigNumber, txData?: Tx): Promise<string>;
        estimateGasAsync(_token: string, _owner: string, _quantity: BigNumber, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_token: string, _owner: string, _quantity: BigNumber, txData?: Tx): string;
        callAsync(_token: string, _owner: string, _quantity: BigNumber, txData?: Tx): Promise<void>;
    };
    decrementTokenOwner: {
        sendTransactionAsync(_token: string, _owner: string, _quantity: BigNumber, txData?: Tx): Promise<string>;
        estimateGasAsync(_token: string, _owner: string, _quantity: BigNumber, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_token: string, _owner: string, _quantity: BigNumber, txData?: Tx): string;
        callAsync(_token: string, _owner: string, _quantity: BigNumber, txData?: Tx): Promise<void>;
    };
    transferBalance: {
        sendTransactionAsync(_token: string, _from: string, _to: string, _quantity: BigNumber, txData?: Tx): Promise<string>;
        estimateGasAsync(_token: string, _from: string, _to: string, _quantity: BigNumber, txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_token: string, _from: string, _to: string, _quantity: BigNumber, txData?: Tx): string;
        callAsync(_token: string, _from: string, _to: string, _quantity: BigNumber, txData?: Tx): Promise<void>;
    };
    batchWithdrawTo: {
        sendTransactionAsync(_tokens: string[], _to: string, _quantities: BigNumber[], txData?: Tx): Promise<string>;
        estimateGasAsync(_tokens: string[], _to: string, _quantities: BigNumber[], txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_tokens: string[], _to: string, _quantities: BigNumber[], txData?: Tx): string;
        callAsync(_tokens: string[], _to: string, _quantities: BigNumber[], txData?: Tx): Promise<void>;
    };
    batchIncrementTokenOwner: {
        sendTransactionAsync(_tokens: string[], _owner: string, _quantities: BigNumber[], txData?: Tx): Promise<string>;
        estimateGasAsync(_tokens: string[], _owner: string, _quantities: BigNumber[], txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_tokens: string[], _owner: string, _quantities: BigNumber[], txData?: Tx): string;
        callAsync(_tokens: string[], _owner: string, _quantities: BigNumber[], txData?: Tx): Promise<void>;
    };
    batchDecrementTokenOwner: {
        sendTransactionAsync(_tokens: string[], _owner: string, _quantities: BigNumber[], txData?: Tx): Promise<string>;
        estimateGasAsync(_tokens: string[], _owner: string, _quantities: BigNumber[], txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_tokens: string[], _owner: string, _quantities: BigNumber[], txData?: Tx): string;
        callAsync(_tokens: string[], _owner: string, _quantities: BigNumber[], txData?: Tx): Promise<void>;
    };
    batchTransferBalance: {
        sendTransactionAsync(_tokens: string[], _from: string, _to: string, _quantities: BigNumber[], txData?: Tx): Promise<string>;
        estimateGasAsync(_tokens: string[], _from: string, _to: string, _quantities: BigNumber[], txData?: Tx): Promise<number>;
        getABIEncodedTransactionData(_tokens: string[], _from: string, _to: string, _quantities: BigNumber[], txData?: Tx): string;
        callAsync(_tokens: string[], _from: string, _to: string, _quantities: BigNumber[], txData?: Tx): Promise<void>;
    };
    getOwnerBalance: {
        callAsync(_token: string, _owner: string, defaultBlock?: any): Promise<BigNumber>;
    };
    deploy(data: string, args: any[]): Promise<any>;
    static deployed(web3: Web3, defaults: Tx): Promise<VaultContract>;
    static at(address: string, web3: Web3, defaults: Tx): Promise<VaultContract>;
    constructor(web3ContractInstance: Contract, defaults: Tx);
    static getAbi(): ABIDefinition[];
}
