import { Address } from 'set-protocol-utils';
import { BigNumber } from 'bignumber.js';
import { UpdatableOracleMockContract } from 'set-protocol-oracles';
import { CoreMockContract, LinearAuctionLiquidatorContract, OracleWhiteListContract, RebalanceAuctionModuleContract, SetTokenContract, SetTokenFactoryContract, StandardTokenMockContract, TransferProxyContract, VaultContract, RebalancingSetTokenV3Contract, RebalancingSetTokenV3FactoryContract, WhiteListContract, FixedFeeCalculatorContract } from '../contracts';
export interface BaseSetConfig {
    set1Components?: Address[];
    set2Components?: Address[];
    set3Components?: Address[];
    set1Units?: BigNumber[];
    set2Units?: BigNumber[];
    set3Units?: BigNumber[];
    set1NaturalUnit?: BigNumber;
    set2NaturalUnit?: BigNumber;
    set3NaturalUnit?: BigNumber;
}
export interface PriceUpdate {
    component1Price?: BigNumber;
    component2Price?: BigNumber;
    component3Price?: BigNumber;
}
export interface ComponentConfig {
    component1Price?: BigNumber;
    component2Price?: BigNumber;
    component3Price?: BigNumber;
    component1Decimals?: number;
    component2Decimals?: number;
    component3Decimals?: number;
}
export declare class RebalanceTestSetup {
    private _contractOwnerAddress;
    private _coreHelper;
    private _erc20Helper;
    private _oracleHelper;
    private _liquidatorHelper;
    private _valuationHelper;
    private _feeCalculatorHelper;
    core: CoreMockContract;
    transferProxy: TransferProxyContract;
    vault: VaultContract;
    setTokenFactory: SetTokenFactoryContract;
    rebalanceAuctionModule: RebalanceAuctionModuleContract;
    rebalancingFactory: RebalancingSetTokenV3FactoryContract;
    rebalancingComponentWhiteList: WhiteListContract;
    liquidatorWhitelist: WhiteListContract;
    fixedFeeCalculator: FixedFeeCalculatorContract;
    feeCalculatorWhitelist: WhiteListContract;
    linearAuctionLiquidator: LinearAuctionLiquidatorContract;
    component1: StandardTokenMockContract;
    component2: StandardTokenMockContract;
    component3: StandardTokenMockContract;
    component1Price: BigNumber;
    component2Price: BigNumber;
    component3Price: BigNumber;
    set1: SetTokenContract;
    set2: SetTokenContract;
    set3: SetTokenContract;
    set1Components: Address[];
    set2Components: Address[];
    set3Components: Address[];
    set1Units: BigNumber[];
    set2Units: BigNumber[];
    set3Units: BigNumber[];
    set1NaturalUnit: BigNumber;
    set2NaturalUnit: BigNumber;
    set3NaturalUnit: BigNumber;
    component1Oracle: UpdatableOracleMockContract;
    component2Oracle: UpdatableOracleMockContract;
    component3Oracle: UpdatableOracleMockContract;
    oracleWhiteList: OracleWhiteListContract;
    rebalancingSetToken: RebalancingSetTokenV3Contract;
    constructor(contractOwnerAddress: Address);
    initialize(from?: Address): Promise<void>;
    initializeBaseSets(config?: BaseSetConfig): Promise<void>;
    initializeComponents(config?: ComponentConfig): Promise<void>;
    initializeCore(from?: Address): Promise<void>;
    setRebalancingSet(rebalancingSet: RebalancingSetTokenV3Contract): void;
    mintRebalancingSets(rebalancingSetQuantity: BigNumber): Promise<void>;
    approveComponentsToAddress(toApprove: Address): Promise<void>;
    jumpTimeAndUpdateOracles(timeIncrease: BigNumber, newPrices: PriceUpdate): Promise<void>;
}
