/// <reference types="node" />
import { Address } from 'set-protocol-utils';
import { CoreContract, CoreMockContract, SetTokenContract, RebalancingSetTokenV3Contract, VaultContract } from '../contracts';
import { BigNumber } from 'bignumber.js';
import { RebalancingSetV2Helper } from './rebalancingSetV2Helper';
declare type CoreLikeContract = CoreMockContract | CoreContract;
export declare class RebalancingSetV3Helper extends RebalancingSetV2Helper {
    /**
     * addressConfig [factory, manager, liquidator, initialSet, componentWhiteList,
     *                liquidatorWhiteList, feeRecipient]
     * [0]factory                   Factory used to create the Rebalancing Set
     * [1]manager                   Address that is able to propose the next Set
     * [2]liquidator                Address of the liquidator contract
     * [3]initialSet                Initial set that collateralizes the Rebalancing set
     * [4]componentWhiteList        Whitelist that nextSet components are checked against during propose
     * [5]liquidatorWhiteList       Whitelist of valid liquidators
     * [6]feeRecipient              Address that receives any incentive fees
     *
     * uintConfig [unitShares, naturalUnit, rebalanceInterval, rebalanceFailPeriod, lastRebalanceTimestamp,
     *             entryFee, rebalanceFee]
     * [0]initialUnitShares         Units of currentSet that equals one share
     * [1]naturalUnit               The minimum multiple of Sets that can be issued or redeemed
     * [2]rebalanceInterval:        Minimum amount of time between rebalances
     * [3]rebalanceFailPeriod:      Time after auctionStart where something in the rebalance has gone wrong
     * [4]lastRebalanceTimestamp:   Time of the last rebalance; Allows customized deployments
     * [5]entryFee:                 Mint fee represented in a scaled percentage value
     * [6]rebalanceFee:             Rebalance fee represented in a scaled percentage value
     *
     */
    deployRebalancingSetTokenV3Async(addressConfig: Address[], bigNumberConfig: BigNumber[], name?: string, symbol?: string, from?: Address): Promise<RebalancingSetTokenV3Contract>;
    createRebalancingTokenV3Async(core: CoreLikeContract, factory: Address, componentAddresses: Address[], units: BigNumber[], naturalUnit: BigNumber, callData?: string, name?: string, symbol?: string, from?: Address): Promise<RebalancingSetTokenV3Contract>;
    createDefaultRebalancingSetTokenV3Async(core: CoreLikeContract, factory: Address, manager: Address, liquidator: Address, feeRecipient: Address, rebalanceFeeCalculator: Address, initialSet: Address, failRebalancePeriod: BigNumber, lastRebalanceTimestamp: BigNumber, entryFee?: BigNumber, rebalanceFee?: BigNumber, initialUnitShares?: BigNumber): Promise<RebalancingSetTokenV3Contract>;
    getExpectedIncentiveFeeUnitShares(rebalancingSetToken: RebalancingSetTokenV3Contract, currentSet: SetTokenContract, vault: VaultContract): Promise<BigNumber>;
    generateRebalancingSetTokenV3CallData(managerAddress: Address, liquidatorAddress: Address, feeRecipient: Address, rebalanceFeeCalculator: Address, rebalanceInterval: BigNumber, failRebalancePeriod: BigNumber, lastRebalanceTimestamp: BigNumber, entryFee: BigNumber, rebalanceFeeCalculatorCalldata: Buffer[]): string;
}
export {};
